[Scummvm-cvs-logs] SF.net SVN: scummvm:[47791] scummvm/trunk/engines/sci

mthreepwood at users.sourceforge.net mthreepwood at users.sourceforge.net
Mon Feb 1 05:14:16 CET 2010


Revision: 47791
          http://scummvm.svn.sourceforge.net/scummvm/?rev=47791&view=rev
Author:   mthreepwood
Date:     2010-02-01 04:14:16 +0000 (Mon, 01 Feb 2010)

Log Message:
-----------
kPlatform(0) should return the SCI platform number. Fixes playing AVI's in KQ7 Windows. Also, adding/updating detection entries for KQ7 Windows.

Modified Paths:
--------------
    scummvm/trunk/engines/sci/detection_tables.h
    scummvm/trunk/engines/sci/engine/kmisc.cpp

Modified: scummvm/trunk/engines/sci/detection_tables.h
===================================================================
--- scummvm/trunk/engines/sci/engine/kmisc.cpp	2010-02-01 03:59:48 UTC (rev 47790)
+++ scummvm/trunk/engines/sci/engine/kmisc.cpp	2010-02-01 04:14:16 UTC (rev 47791)
@@ -320,8 +320,6 @@
 	uint16 operation = (argc == 0) ? 0 : argv[0].toUint16();
 
 	switch (operation) {
-	case kPlatformUnk0:
-		return make_reg(0, !isWindows);
 	case kPlatformCDSpeed:
 		// TODO: Returns CD Speed?
 		warning("STUB: kPlatform(CDSpeed)");
@@ -333,6 +331,7 @@
 		// TODO: Some sort of CD check?
 		warning("STUB: kPlatform(CDCheck)");
 		break;
+	case kPlatformUnk0:
 	case kPlatformGetPlatform:
 		return make_reg(0, (isWindows) ? kSciPlatformWindows : kSciPlatformDOS);
 	case kPlatformUnk5:


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list
--- scummvm/trunk/engines/sci/detection_tables.h	2010-02-01 03:59:48 UTC (rev 47790)
+++ scummvm/trunk/engines/sci/detection_tables.h	2010-02-01 04:14:16 UTC (rev 47791)
@@ -1076,22 +1076,30 @@
 		{NULL, 0, NULL, 0}},
 		Common::EN_ANY, Common::kPlatformWindows, 0, GUIO_NOSPEECH	},
 
 	// King's Quest 7 - English DOS (from the King's Quest Collection)
 	// Executable scanning reports "2.100.002", VERSION file reports "1.4"
 	{"kq7", "", {
 		{"resource.map", 0, "2be9ab94429c721af8e05c507e048a15", 18697},
 		{"resource.000", 0, "eb63ea3a2c2469dc2d777d351c626404", 203882535},
 		{NULL, 0, NULL, 0}},
-		Common::EN_ANY, Common::kPlatformPC, 0, GUIO_NOSPEECH	},
+		Common::EN_ANY, Common::kPlatformWindows, 0, GUIO_NOSPEECH	},
 
 	// King's Quest 7 - English DOS (from FRG)
-	// SCI interpreter version 2.100.002
+	// SCI interpreter version 2.100.002, VERSION file reports "2.00b"
 	{"kq7", "", {
 		{"resource.map", 0, "8676b0fbbd7362989a029fe72fea14c6", 18709},
 		{"resource.000", 0, "51c1ead1163e19a2de8f121c39df7a76", 200764100},
 		{NULL, 0, NULL, 0}},
 		Common::EN_ANY, Common::kPlatformPC, 0, GUIO_NOSPEECH	},
 
+	// King's Quest 7 - English Windows (from FRG)
+	// SCI interpreter version 2.100.002, VERSION file reports "2.00b"
+	{"kq7", "", {
+		{"resource.map", 0, "8676b0fbbd7362989a029fe72fea14c6", 18709},
+		{"resource.000", 0, "51c1ead1163e19a2de8f121c39df7a76", 200764100},
+		{NULL, 0, NULL, 0}},
+		Common::EN_ANY, Common::kPlatformWindows, 0, GUIO_NOSPEECH	},
+
 	// King's Quest 7 - German Windows (supplied by markcoolio in bug report #2727402)
 	// SCI interpreter version 2.100.002
 	{"kq7", "", {
@@ -1076,22 +1076,30 @@
 		Common::EN_ANY, Common::kPlatformWindows, 0, GUIO_NOSPEECH	},
 
-	// King's Quest 7 - English DOS (from the King's Quest Collection)
+	// King's Quest 7 - English Windows (from the King's Quest Collection)
 	// Executable scanning reports "2.100.002", VERSION file reports "1.4"
 	{"kq7", "", {

Modified: scummvm/trunk/engines/sci/engine/kmisc.cpp
===================================================================